import fetch from './fetch.js'
import {buildHeaders} from '../api/common.js'
import {describe, test, expect, vi} from 'vitest'
import nodeFetch, {Response} from 'node-fetch'
import type {RequestInit, RequestInfo} from 'node-fetch'

vi.mock('node-fetch')
vi.mock('../api/common.js')

describe('fetch', () => {
  test('delegates the fetch to node-fetch', async () => {
    // Given
    const url: RequestInfo = 'https://shopify.com'
    const init: RequestInit = {}
    const response = new Response(null, undefined)

    vi.mocked(nodeFetch).mockResolvedValue(response)

    // When
    const got = await fetch(url, init)

    // Then
    expect(vi.mocked(nodeFetch)).toHaveBeenCalledWith(url, init)
    expect(got).toBe(response)
  })
})

describe('shopifyFetch', () => {
  test('it includes the default headers', async () => {
    // Given
    vi.mocked(buildHeaders).mockResolvedValue({foo: 'bar'})
    const url: RequestInfo = 'https://shopify.com'
    const init: RequestInit = {
      headers: {
        test: 'value',
      },
    }
    const response = new Response(null, undefined)
    vi.mocked(nodeFetch).mockResolvedValue(response)

    // When
    const got = await fetch(url, init)

    // Then
    expect(vi.mocked(nodeFetch)).toHaveBeenCalledWith(url, init)
    expect(got).toBe(response)
  })
})
